@@ -63,7 +63,7 @@ else:
         pass
 
 APPNAME = 'PDF Arranger'
-VERSION = '1.3.0'
+VERSION = '1.3.1'
 WEBSITE = 'https://github.com/jeromerobert/pdfarranger'
 LICENSE = 'GNU General Public License (GPL) Version 3.'
 
@@ -546,6 +546,9 @@ class PdfArranger(Gtk.Application):
     def close_application(self, widget=None, event=None, data=None):
         """Termination"""
 
+        # Prevent gtk errors when closing with everything selected
+        self.iconview.unselect_all()
+
         if self.rendering_thread:
             self.rendering_thread.quit = True
             self.rendering_thread.join()
@@ -564,15 +567,20 @@ class PdfArranger(Gtk.Application):
     def choose_export_pdf_name(self, only_selected=False):
         """Handles choosing a name for exporting """
 
-        chooser = Gtk.FileChooserNative(title=_('Export ...'),
-                                        action=Gtk.FileChooserAction.SAVE)
+        chooser = Gtk.FileChooserDialog(title=_('Export ...'),
+                                        parent=self.window,
+                                        action=Gtk.FileChooserAction.SAVE,
+                                        buttons=(Gtk.STOCK_CANCEL,
+                                                 Gtk.ResponseType.CANCEL,
+                                                 Gtk.STOCK_SAVE,
+                                                 Gtk.ResponseType.ACCEPT))
         chooser.set_do_overwrite_confirmation(True)
         if len(self.pdfqueue) > 0:
             chooser.set_filename(self.pdfqueue[0].filename)
         chooser.set_current_folder(self.export_directory)
         filter_pdf = Gtk.FileFilter()
         filter_pdf.set_name(_('PDF files'))
-        filter_pdf.add_mime_type('application/pdf')
+        filter_pdf.add_pattern('*.pdf')
         chooser.add_filter(filter_pdf)
 
         filter_all = Gtk.FileFilter()
@@ -636,11 +644,16 @@ class PdfArranger(Gtk.Application):
 
     def on_action_add_doc_activate(self, action, param, unknown):
         """Import doc"""
-        chooser = Gtk.FileChooserNative(title=_('Import...'),
-                                        action=Gtk.FileChooserAction.OPEN)
+        chooser = Gtk.FileChooserDialog(title=_('Import...'),
+                                        parent=self.window,
+                                        action=Gtk.FileChooserAction.OPEN,
+                                        buttons=(Gtk.STOCK_CANCEL,
+                                                 Gtk.ResponseType.CANCEL,
+                                                 Gtk.STOCK_OPEN,
+                                                 Gtk.ResponseType.ACCEPT))
         chooser.set_current_folder(self.import_directory)
         chooser.set_select_multiple(True)
-
+        # TODO: Factorize, file filters are the same in choose_export_pdf_name
         filter_all = Gtk.FileFilter()
         filter_all.set_name(_('All files'))
         filter_all.add_pattern('*')
@@ -648,7 +661,7 @@ class PdfArranger(Gtk.Application):
 
         filter_pdf = Gtk.FileFilter()
         filter_pdf.set_name(_('PDF files'))
-        filter_pdf.add_mime_type('application/pdf')
+        filter_pdf.add_pattern('*.pdf')
         chooser.add_filter(filter_pdf)
         chooser.set_filter(filter_pdf)
 
@@ -657,9 +670,7 @@ class PdfArranger(Gtk.Application):
             adder = PageAdder(self)
             for filename in chooser.get_filenames():
                 try:
-                    warnmsg = adder.addpages(filename)
-                    if warnmsg:
-                        print(warnmsg)
+                    adder.addpages(filename)
                 except Exception as e:
                     traceback.print_exc()
                     chooser.destroy()
@@ -996,7 +1007,7 @@ class PdfArranger(Gtk.Application):
             new_angle = new_angle % 360
             model.set_value(treeiter, 6, new_angle)
             self.update_geometry(treeiter)
-        return rotate_times is not 0 and len(selection) > 0
+        return rotate_times != 0 and len(selection) > 0
 
     def crop_page_dialog(self, action, parameter, unknown):
         """Opens a dialog box to define margins for page cropping"""
@@ -1179,31 +1190,12 @@ class PageAdder(object):
         #: Where to insert pages. If None pages are inserted at the end
         self.treerowref = None
 
-    @staticmethod
-    def __validate(filename):
-        if not os.path.isfile(filename):
-            return _('File %s does not exist') % filename
-        f = Gio.File.new_for_path(filename)
-        mime_type = f.query_info('standard::content-type', 0, None).get_content_type()
-        expected_mime_type = 'application/pdf' if os.name != 'nt' else '.pdf'
-        if mime_type == expected_mime_type:
-            return ""
-        elif mime_type[:34] == 'application/vnd.oasis.opendocument':
-            return _('OpenDocument not supported yet!')
-        elif mime_type[:5] == 'image':
-            return _('Image file not supported yet!')
-        else:
-            return _('File type "%s" not supported!') % mime_type
-
     def move(self, treerowref, before):
         """ Insert pages at the given location """
         self.before = before
         self.treerowref = treerowref
 
     def addpages(self, filename, page=-1, angle=0, crop=None):
-        warnmsg = self.__validate(filename)
-        if warnmsg:
-            return warnmsg
         crop = [0] * 4 if crop is None else crop
         pdfdoc = None
         for i, it_pdfdoc in enumerate(self.app.pdfqueue):
@@ -1241,7 +1233,6 @@ class PageAdder(object):
                                crop[2], crop[3],     # 9-10
                                w,h,                 # 11-12
                                2.))                 # 13 FIXME
-        return ""
 
     def commit(self):
         if len(self.pages) == 0:
